#[repr(i32)]pub enum CommandResponseType {
Startresponse = 0,
Stopresponse = 1,
Statusresponse = 2,
Synthesisresponse = 3,
}Variants
Startresponse = 0
Synthesis startet
Stopresponse = 1
Synthesis stopped
Statusresponse = 2
Response contains status information
Synthesisresponse = 3
Response contains SpeechResponses
Implementations
Sourceimpl CommandResponseType
impl CommandResponseType
Sourcepub fn from_i32(value: i32) -> Option<CommandResponseType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CommandResponseType>
Converts an i32 to a CommandResponseType, or None if value is not a valid variant.
Sourceimpl CommandResponseType
impl CommandResponseType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.