pub struct ServerCommand {
pub command_type: i32,
pub command_data: Vec<u8>,
pub speech_request: Option<SpeechRequest>,
}Expand description
A command that is sent to the speech engine. START_REQUEST has to encapsulate a SpeechRequest.
Fields
command_type: i32command_data: Vec<u8>speech_request: Option<SpeechRequest>Implementations
Sourceimpl ServerCommand
impl ServerCommand
Sourcepub fn command_type(&self) -> CommandType
pub fn command_type(&self) -> CommandType
Returns the enum value of command_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command_type(&mut self, value: CommandType)
pub fn set_command_type(&mut self, value: CommandType)
Sets command_type to the provided enum value.