Aristech TTS-Client
The Aristech TTS-Client is a client library for the Aristech TTS-Server.
Modules
- tts_
services - The tts_services module contains types and functions generated from the Aristech TTS proto files.
Structs
- Auth
- The Auth struct holds the token and secret needed to authenticate with the server.
- Auth
Interceptor - The AuthInterceptor struct is used to intercept requests to the server and add the authentication headers.
- TlsOptions
- The TlsOptions struct holds the tls options needed to communicate with the server.
Functions
- clear_
cache - Clears the cache of the server, removing all cached audio data.
- get_
audio - This is just an alias for synthesize
- get_
client - Creates a new TtsClient to communicate with the server.
- get_
phoneset - Gets the phoneset for the given voice from the server.
- get_
transcription - Gets the transcription for a word for a specific voice from the server.
- get_
voices - Gets the list of available voices from the server.
- synthesize
- Synthesizes the given text with the given options and returns the audio data. Currently only raw and wav audio formats are supported. If the audio format is set to wav (default), the audio data will be prepended with a wave header.
Type Aliases
- TtsClient
- The TtsClient type is a type alias for the TtsServiceClient with the AuthInterceptor.